@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Control-change based RtController filters
 
-our $VERSION = '0.0801';
+our $VERSION = '0.0802';
 
 use v5.36;
 
@@ -113,9 +113,10 @@ sub single ($self, $device, $dt, $event) {
     my ($ev, $chan, $note, $val) = $event->@*;
     return 0 if defined $self->trigger && $note != $self->trigger;
 
-    my $cc = [ 'control_change', $self->channel, $self->control, $self->value ];
+    my $value = $self->value || $val;
+    my $cc = [ 'control_change', $self->channel, $self->control, $value ];
     $self->rtc->send_it($cc);
-    return 0;
+    return 1;
 }
 
 
@@ -310,7 +311,7 @@ MIDI::RtController::Filter::CC - Control-change based RtController filters
 
 =head1 VERSION
 
-version 0.0801
+version 0.0802
 
 =head1 SYNOPSIS
 
